/**
 * Site Urls
 * @enum {string} Urls
 */
'use strict'

const { isProduction } = require('@the-/check')
const theHash = require('@the-/hash')
const pkg = require('../package')

const prodAssetURL = `/v${pkg.version}`

module.exports = Object.freeze(
  /** @lends Urls */
  {
    // -----------------------------------
    // Css
    // -----------------------------------
    ...{
      CSS_BUNDLE_URL: '/build/bundle.css',
      CSS_FLATPICKR_URL: '/css/flatpickr.min.css',
      CSS_FONT_URL: '/css/fontawesome-all.css',
      CSS_NORMALIZE_URL: '/css/normalize.css',
      CSS_THEME_URL: '/css/theme.css',
    },

    // -----------------------------------
    // Error
    // -----------------------------------
    ...{
      ERROR_FORBIDDEN_URL: '/errors/forbidden',
      ERROR_NOTFOUND_URL: '/errors/not-found',
    },

    // -----------------------------------
    // Icon
    // -----------------------------------
    ...{
      ICON_URL: '/images/app-icon.png',
    },

    // -----------------------------------
    // JS
    // -----------------------------------
    ...{
      JS_BUNDLE_URL: '/build/bundle.js',
      JS_CHUNK_BASE_URL: isProduction() ? prodAssetURL : `/build`,
      JS_ROOT_SERVICE_WORKER_URL: '/RootServiceWorker.js',
      JS_SHIM_URL: '/js/es5-shim.min.js',
    },

    // -----------------------------------
    // Production
    // -----------------------------------
    ...{
      PROD_ASSET_URL: prodAssetURL,
      PROD_CSS_BUNDLE_URL: `${prodAssetURL}/bundle.css`,
      PROD_JS_BUNDLE_URL: `${prodAssetURL}/bundle.js`,
    },

    // -----------------------------------
    // Top
    // -----------------------------------
    ...{
      TOP_URL: '/',
    },
  },
)

if (!isProduction()) {
  module.exports = theHash.proxy(module.exports, {
    name: 'Urls',
    unknownCheck: true,
  })
}
